Tutorial Guide
**************

We think, that the easiest way to learn is learning-by-doing. For this, the following example will introduce you to the
most important components of the Balder system, by creating Balder tests for an example project which you can find in
many projects and companies.

But before you start, make sure that you have read the `Getting Started Guide <Getting Started>`_, because this guide
explains the basic concepts of Balder.

.. toctree::
    :maxdepth: 2
    :caption: Getting Started

    00_intro.rst
    01_create_scenario.rst
    02_single_setup.rst
    03_double_setup.rst
    04_add_fixtures.rst
    05_one_common_setup.rst
    06_develop_with_connection_trees.rst
    07_convert_in_balderhub.rst
